{ config, lib, pkgs, inputs, ... }:{

  imports = [
    ./hardware-configuration.nix
    ./networking.nix # generated at runtime by nixos-infect
    ./disko-config.nix
  ];

  boot.tmp.cleanOnBoot = true;
  boot.loader.grub.enable = true;
  zramSwap.enable = true;
  networking.hostName = "services-nixos";
  networking.domain = "";
  services.openssh.enable = true;
  users.users.root.openssh.authorizedKeys.keys = [''ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIGbzcaEyzlGJkDL8EMcVmrAWRlyYtilTjpIR2VGxkMHo'' ''ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFvtBCUQEi7r6mXdaULEaMMvGH1IWZBX9tXpjbIECar2'' ];

  environment.systemPackages = with pkgs; [
    wget
    home-manager
    curl
    git-lfs
    rsync
    gnupg
    util-linux
  ];


  users.users.emenel = {
    openssh.authorizedKeys.keys = [''ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIGbzcaEyzlGJkDL8EMcVmrAWRlyYtilTjpIR2VGxkMHo'' ''ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFvtBCUQEi7r6mXdaULEaMMvGH1IWZBX9tXpjbIECar2'' ];

    isNormalUser = true;
    description = "emenel";
    extraGroups = [
      "networkmanager"
      "network"
      "wheel"
      "uinput"
    ];
    packages = with pkgs; [
      git
    ];
  };

  services = {
    forgejo = {
      enable = true;
      lfs.enable = true;
      settings = {
        server = {
          HTTP_PORT = 12345;
        };
      };
    };
  };

  system.stateVersion = "25.05"; # Did you read the comment?


}
